@@ -1,7 +1,7 @@
 use strictures 1;
 package Mojito::Collection::CRUD::Mongo;
 {
-  $Mojito::Collection::CRUD::Mongo::VERSION = '0.23';
+  $Mojito::Collection::CRUD::Mongo::VERSION = '0.24';
 }
 use MongoDB::OID;
 use 5.010;
@@ -132,6 +132,49 @@ sub collections_for_page {
     return @collection_ids;
 }
 
+sub update_collection_membership {
+    my ($self, $params) = @_;
+
+    my $collection_ids = $params->{collection_select};
+     # Want to coerce (single select) SCALAR into an ArrayRef (happens w/ Dancer params)
+    if (ref($collection_ids) ne 'ARRAY') {
+        warn "Coercing collection select params into an ArrefRef" if $ENV{MOJITO_DEBUG};
+        $collection_ids = [$collection_ids];
+    }
+    # Have we assigned the page to at least one collection?
+    if (defined $collection_ids->[0]) {
+        my $cursor = $self->db->collection->find({collected_page_ids => $params->{mongo_id}});
+        my %HAVE;
+        while (my $collection = $cursor->next) {
+            $HAVE{$collection->{_id}} = 1;
+        }
+        my %WANT = map { $_ => 1 } @{$collection_ids};
+        # collection_id of zero in this case means we don't want to assign
+        # the page to any collection
+        %WANT = () if not $collection_ids->[0];
+        foreach my $collection_id (keys %WANT) {
+            if (not $HAVE{$collection_id}) {
+            # add page_id to the collection
+                my $collection = $self->collector->read($collection_id);
+                push @{$collection->{collected_page_ids}}, $params->{mongo_id};
+                my $oid = MongoDB::OID->new( value => $collection_id );
+                $self->db->collection->update({_id => $oid}, $collection);
+            }
+        }
+        foreach my $collection_id (keys %HAVE) {
+            if (not $WANT{$collection_id}) {
+            # remove the page_id from the collection
+                my $oid = MongoDB::OID->new( value => $collection_id );
+                $self->db->collection->update(
+                    { _id => $oid },
+                    { '$pull' => {collected_page_ids => $params->{mongo_id} } },
+                );
+            }
+        }
+    }
+    
+}
+
 =head2 BUILD
 
 Set the collection we want to work with.
